@@ -1,4 +1,4 @@
-# Copyright (C) 2020 Serghei Iakovlev <egrep@protonmail.ch>
+# Copyright (C) 2020, 2021 Serghei Iakovlev <egrep@protonmail.ch>
 #
 # This file is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -16,7 +16,7 @@
 import os
 import sys
 import textwrap as _textwrap
-from argparse import ArgumentParser, HelpFormatter
+from argparse import SUPPRESS, ArgumentParser, HelpFormatter
 from os import environ as env
 
 from gstore import __copyright__, __version__
@@ -24,7 +24,8 @@ from .client import DEFAULT_HOST, TOKEN_NAMES
 
 
 class LineBreaksFormatter(HelpFormatter):
-    """ArgParse help formatter that allows line breaks in the usage messages
+    """
+    ArgParse help formatter that allows line breaks in the usage messages
     and argument help strings.
 
     Normally to include newlines in the help output of argparse, you have
@@ -69,15 +70,14 @@ def get_version_str():
 
 
 def get_token_from_env():
-    """
-    Get authentication token for GitHub API from environment variables.
+    """ Get authentication token for GitHub API from environment variables.
 
     The order of searching for a token in environment variables:
     * GH_TOKEN, GITHUB_TOKEN (in order of precedence)
     * GH_ENTERPRISE_TOKEN, GITHUB_ENTERPRISE_TOKEN (in order of precedence)
 
     :returns: An authentication token for github.com API requests
-    :rtype: str|None
+    :rtype: str or None
     """
     token = None
 
@@ -90,39 +90,61 @@ def get_token_from_env():
 
 
 def argparse():
-    p = ArgumentParser(
+    parser = ArgumentParser(
         description='Synchronize GitHub repositories of your organizations.',
-        formatter_class=LineBreaksFormatter)
+        usage='%(prog)s [options] [[--] target]',
+        formatter_class=LineBreaksFormatter,
+        add_help=False,
+    )
 
-    dumpversion_help = ("print the version of the program and don't " +
-                        'do anything else')
-
-    quiet_help = 'silence any informational messages, but not error ones'
     token = get_token_from_env()
 
-    p.add_argument('target', nargs='?', type=str,
-                   default=env.get('GSTORE_DIR', os.getcwd()),
-                   help='base target to sync repos (e.g. folder on disk)')
+    pgroup = parser.add_argument_group('Positional parameters')
 
-    p.add_argument('--token', dest='token', default=token, type=str,
-                   help='an authentication token for GitHub API requests')
-    p.add_argument('--host', dest='host',
-                   default=env.get('GH_HOST', DEFAULT_HOST), type=str,
-                   help='the GitHub API hostname (by default api.github.com)')
-    p.add_argument('--org', dest='org', nargs='*', type=str,
-                   help='organizations you have access to (by default all)')
-    p.add_argument('-v', '--verbose', dest='verbose', action='store_true',
-                   help='enable verbose mode')
-    p.add_argument('-q', '--quiet', dest='quiet', action='store_true',
-                   help=quiet_help)
-    p.add_argument('-V', '--version', action='version',
-                   help="print program's version information and quit",
-                   version=get_version_str())
-    p.add_argument('-dumpversion', action='version', help=dumpversion_help,
-                   version=__version__)
+    pgroup.add_argument('target', nargs='?', type=str,
+                        default=env.get('GSTORE_DIR', os.getcwd()),
+                        help='Base target to sync repos (e.g. folder on disk)')
 
+    ogroup = parser.add_argument_group('Options')
+
+    ogroup.add_argument('-h', '--help', action='help', default=SUPPRESS,
+                        help='Print this help message and quit')
+
+    ogroup.add_argument('--token', dest='token', default=token, type=str,
+                        help='An authentication token for GitHub API requests')
+
+    ogroup.add_argument('--host', dest='host',
+                        default=env.get('GH_HOST', DEFAULT_HOST), type=str,
+                        help='The GitHub API hostname')
+
+    ogroup.add_argument('-o', '--org', dest='org', action='append', type=str,
+                        help='Organization to sync (all if not provided)')
+
+    repo_help = ('Limit sync to the specified repository, ' +
+                 'otherwise sync all repositories (format "org:repo")')
+    ogroup.add_argument('-r', '--repo', dest='repo', action='append',
+                        type=str, help=repo_help)
+
+    ogroup.add_argument('-v', '--verbose', dest='verbose', action='store_true',
+                        help='Increase output verbosity')
+
+    quiet_help = 'Silence any informational messages, but not error ones'
+    ogroup.add_argument('-q', '--quiet', dest='quiet', action='store_true',
+                        help=quiet_help)
+
+    ogroup.add_argument('-V', '--version', action='version',
+                        help="Print program's version information and quit",
+                        version=get_version_str())
+
+    dumpversion_help = ("Print the version of the program and don't " +
+                        'do anything else')
+    ogroup.add_argument('-dumpversion', action='version',
+                        help=dumpversion_help, version=__version__)
+
+    # Show help message and exit when Gstore is called without any argument and
+    # there are not enough environment variables for normal operation.
     if len(sys.argv) == 1 and token is None:
-        p.print_help(sys.stderr)
+        parser.print_help(sys.stderr)
         sys.exit(1)
 
-    return p.parse_args()
+    return parser.parse_args()
