@@ -1,4 +1,4 @@
-# Copyright (C) 2020 Serghei Iakovlev <egrep@protonmail.ch>
+# Copyright (C) 2020, 2021 Serghei Iakovlev <egrep@protonmail.ch>
 #
 # This file is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -18,25 +18,31 @@ import logging
 from .args import argparse
 from .client import Client
 from .logger import setup_logger
-from .repo import sync
+from .repo import RepoManager
 
 
 def main():
-    ns = argparse()
-    setup_logger(verbose=ns.verbose, quiet=ns.quiet)
+    args = argparse()
+    setup_logger(verbose=args.verbose, quiet=args.quiet)
 
     logger = logging.getLogger('gstore.cli')
 
     try:
-        client = Client(token=ns.token, api_host=ns.host)
+        client = Client(token=args.token, api_host=args.host)
 
-        if ns.org is None:
+        if args.org is None:
             orgs = client.get_orgs()
         else:
-            orgs = ns.org
+            orgs = client.resolve_orgs(args.org)
+
+        manager = RepoManager(args.target)
 
         for org in orgs:
-            repos = client.get_repos(org)
-            sync(org, repos, ns.target)
-    except Exception as e:
-        logger.critical(e)
+            if args.repo is None:
+                repos = client.get_repos(org)
+            else:
+                repos = client.resolve_repos(args.repo, org)
+
+            manager.sync(org, repos)
+    except Exception as exception:
+        logger.critical(exception)
