@@ -1,4 +1,4 @@
-# Copyright (C) 2020 Serghei Iakovlev <egrep@protonmail.ch>
+# Copyright (C) 2020, 2021 Serghei Iakovlev <egrep@protonmail.ch>
 #
 # This file is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,10 +17,8 @@ import logging
 import sys
 
 
-class DebugFilter(logging.Filter):
-    """
-    Extended standard logging Filter to filer only DEBUG messages.
-    """
+class DebugFilter(logging.Filter):  # pylint: disable=too-few-public-methods
+    """Extended standard logging Filter to filer only DEBUG messages."""
 
     def filter(self, record: logging.LogRecord) -> bool:
         """
@@ -34,10 +32,8 @@ class DebugFilter(logging.Filter):
         return record.levelno == logging.DEBUG
 
 
-class InfoFilter(logging.Filter):
-    """
-    Extended standard logging Filter to filer only INFO messages.
-    """
+class InfoFilter(logging.Filter):  # pylint: disable=too-few-public-methods
+    """Extended standard logging Filter to filer only INFO messages."""
 
     def filter(self, record: logging.LogRecord) -> bool:
         """
@@ -51,43 +47,37 @@ class InfoFilter(logging.Filter):
         return record.levelno == logging.INFO
 
 
-def setup_logger(verbose=False, quiet=False):
+def setup_logger(verbose=False, quiet=False) -> logging.Logger:
     """
     Setup and return the root logger object for the application.
 
     :param bool verbose: Enable debug logging
     :param bool quiet: Disable info logging
+    :rtype: :class:`logging.Logger`
     """
 
     root = logging.getLogger('gstore')
-    log_level = logging.DEBUG
-
-    if quiet:
-        log_level = logging.WARNING
-
-    root.setLevel(log_level)
+    root.setLevel(logging.ERROR if quiet else logging.DEBUG)
 
     formatter = logging.Formatter(
         '%(asctime)s - %(name)s - %(levelname)s - %(message)s'
     )
 
-    if verbose:
-        debug_handler = logging.StreamHandler(sys.stdout)
-        debug_handler.setLevel(logging.DEBUG)
-        debug_handler.addFilter(DebugFilter())
-        debug_handler.setFormatter(formatter)
-        root.addHandler(debug_handler)
+    specs = (
+        {'on': verbose, 'filter': DebugFilter()},
+        {'on': not quiet, 'level': logging.INFO, 'filter': InfoFilter()},
+        {'on': True, 'stream': sys.stderr, 'level': logging.ERROR},
+    )
 
-    if not quiet:
-        info_handler = logging.StreamHandler(sys.stdout)
-        info_handler.setLevel(logging.INFO)
-        info_handler.addFilter(InfoFilter())
-        info_handler.setFormatter(formatter)
-        root.addHandler(info_handler)
+    for spec in specs:
+        if spec['on']:
+            handler = logging.StreamHandler(spec.get('stream', sys.stdout))
+            handler.setLevel(spec.get('level', logging.DEBUG))
+            handler.setFormatter(formatter)
 
-    error_handler = logging.StreamHandler(sys.stderr)
-    error_handler.setLevel(logging.WARNING)
-    error_handler.setFormatter(formatter)
-    root.addHandler(error_handler)
+            if spec.get('filter'):
+                handler.addFilter(spec['filter'])
+
+            root.addHandler(handler)
 
     return root
